'use strict';

var dynamic = require('./generated-dynamic.js');

console.log('main2', dynamic.dynamic, dynamic.dep);
